@@ -27,8 +27,18 @@ int draw_background(const char *arg)
     return 0;
 }
 
-int main(int argc, char *argv[])
+void set_resolution(int x, int y)
+{
+    (void)x;
+    (void)y;
+}
+
+void local_cursor_enable(bool enabled)
+{
+    (void)enabled;
+}
+
+void start_console(void)
 {
     console_ansi_raw();
-    return menu_main(argc, argv);
 }
